@@ -30,7 +30,7 @@ sub doInventory {
 
 
     ### mem convert it to meg's if it comes back in gig's
-    my $mem = $sysprofile->{'Memory'};
+    my $mem = $sysprofile->{'Hardware'}{'Hardware Overview'}{'Memory'};
     if ($mem =~ /GB$/){
         $mem =~ s/\sGB$//;
         $mem = ($mem * 1024);
@@ -96,7 +96,10 @@ sub _getCpus{
 
     my $cores =
         $info->{'Total Number Of Cores'} ? $info->{'Total Number Of Cores'} / $procs :
-                                           1                                        ;
+                                           $info->{'machdep.cpu.core_count'};
+
+    my $threads = $info->{'machdep.cpu.thread_count'};
+
 
     my $manufacturer =
         $type =~ /Intel/i ? "Intel" :
@@ -108,7 +111,7 @@ sub _getCpus{
         CORE         => $cores,
 	MANUFACTURER => $manufacturer,
         NAME         => $type,
-        THREAD       => 1,
+        THREAD       => $threads,
         FAMILYNUMBER => $family,
         MODEL        => $model,
         STEPPING     => $stepping,
@@ -119,7 +122,7 @@ sub _getCpus{
         push @cpus, $cpu;
     }
 
-    return $cpu;
+    return @cpus;
 
 }
 
